@@ -66,7 +66,7 @@ DEFAULT_COLUMNS = {
          'filter', 'pupil', 'fwcpos', 'pwcpos', 'lamp',
          'readpatt', 'nexposur', 'nframes', 'ngroups', 'tframe',
          'nints', 'nresets', 'effexptm as exptime',
-         'pi_name', 'program', 'title',
+         'pi_name', 'program', 'title', 'category',
          'targname', 'prop_ra', 'prop_dec',
          'patttype', 'patt_num', 'pattsize',
          'pridtpts', 'subpxpts',
@@ -82,7 +82,7 @@ DEFAULT_COLUMNS = {
          'filter','pupil', 'lamp',
          'readpatt', 'nexposur', 'nframes', 'ngroups', 'tframe',
          'nints', 'nresets', 'effexptm as exptime',
-         'pi_name', 'program', 'title',
+         'pi_name', 'program', 'title', 'category',
          'targname', 'prop_ra', 'prop_dec', 
          'patttype', 'patt_num', 'pattsize',
          'pridtype', 'pridtpts', 'subpxpat', 'subpxpts', 'smgrdpat', 
@@ -99,7 +99,7 @@ DEFAULT_COLUMNS = {
          'readpatt', 'nexposur', 'nframes', 'ngroups', 'tframe',
          'nints', 'nresets', 'effexptm as exptime',
          'mirngrps', 'mirnfrms', 
-         'pi_name', 'program', 'title',
+         'pi_name', 'program', 'title', 'category',
          'targname', 'prop_ra', 'prop_dec', 
          'patttype', 'patt_num', 'pattsize',
          'pridtpts', 'subpxpts',
@@ -118,7 +118,7 @@ DEFAULT_COLUMNS = {
          'msaconid', 'msametfl', 'msametid', 'msastate', 'preimage',
          'readpatt', 'nexposur', 'nframes', 'ngroups', 'tframe',
          'nints', 'nresets', 'effexptm as exptime',
-         'pi_name', 'program', 'title',
+         'pi_name', 'program', 'title', 'category',
          'targname', 'prop_ra', 'prop_dec', 
          'patttype', 'patt_num', 'pattsize',
          'pridtpts', 'subpxpat', 'subpxpts', 'nod_type', 
@@ -136,7 +136,8 @@ REQUEST = {'service': 'Mast.Jwst.Filtered.Niriss',
 SERVICES = {'NIS':'Mast.Jwst.Filtered.Niriss', 
             'NRC':'Mast.Jwst.Filtered.Nircam',
             'MIR':'Mast.Jwst.Filtered.Miri',
-            'NRS':'Mast.Jwst.Filtered.Nirspec'}
+            'NRS':'Mast.Jwst.Filtered.Nirspec', 
+            'FGS':'Mast.Jwst.Filtered.Fgs'}
 
 FILTER_EXAMPLES = [{'paramName':
                     'productLevel', 'values': ['2a','2b']},
@@ -344,7 +345,7 @@ def fix_jwst_sregions(res):
     from sregion import SRegion
 
     siaf = {}
-    for ins in ['MIRI','NIRISS','NIRCAM','NIRSPEC']:
+    for ins in ['MIRI','NIRISS','NIRCAM','NIRSPEC','FGS']:
         siaf[ins] = pysiaf.Siaf(ins)
 
     s_region = []
@@ -359,10 +360,13 @@ def fix_jwst_sregions(res):
         if not res['xoffset'][i]:
             s_region.append(res['s_region'][i])
             continue
-
+        
         aper_name = res['apername'][i]
-        dx, dy = 0., 0.
-
+                
+        if res['pps_aper'][i] not in siaf[res['instrume'][i]].apertures:
+            s_region.append(res['s_region'][i])
+            continue
+            
         ap_ref = siaf[res['instrume'][i]].apertures[res['pps_aper'][i]]
 
         if aper_name == 'MIRIM_FULL':
@@ -461,6 +465,8 @@ def match_dataportal_columns(res):
 
         res[c] = fill_cols[c]
     
+    res['orig-filter'] = res['filter']
+    
     # Translate columns
     col_translate = {'targname':'target', 
                      'filter-pupil':'filter',
@@ -480,8 +486,6 @@ def match_dataportal_columns(res):
         if c in res.colnames:
             res[col_translate[c]] = res[c]
 
-    res['orig-filter'] = res['filter']
-
     res.remove_column('filter')
     res['filter'] = res['inst-mode']
 
@@ -493,9 +497,10 @@ def match_dataportal_columns(res):
         f_i = f_i.replace('.GRISMR','').replace('.GRISMC','')
 
         inst_i = {'NIRCAM':'NC', 
-                  'NIRISS':'NS',
+                  'NIRISS':'NI',
                   'MIRI':'MI',
-                  'NIRSPEC':'NS'}[inst]
+                  'NIRSPEC':'NS',
+                  'FGS':'FGS'}[inst]
                   
         if 'GR' in f_i:
             res['filter'][i] = f'{f_i}'
@@ -575,8 +580,10 @@ def query_jwst(instrument='NIS', columns='*', filters=CALIB_FILTERS+FULL_SUBARRA
         tab['dt'].format = '.2f'
     
     if ('program' in tab.colnames) & ('pi_name' in tab.colnames):
-        tab['prog_pi'] = [f'{prog} {pi}'
-                          for prog, pi in zip(tab['program'], tab['pi_name'])]
+        tab['prog_pi'] = [f'{ca:>4}-{pr} {pi}'
+                          for ca, pr, pi in zip(tab['category'], 
+                                                tab['program'],
+                                                tab['pi_name'])]
     
     if ('filter' in tab.colnames) & ('pupil' in tab.colnames):
         tab['filter-pupil'] = [f'{f}-{p}'.replace('---','')
