@@ -6,6 +6,8 @@ import inspect
 import json
 
 import warnings
+import logging
+
 import numpy as np
 
 from astropy.table import Table
@@ -252,21 +254,113 @@ def new_mastJson2Table(query_content):
         return tabs
 
 
-def download_from_mast(tab, out_path='./', verbose=True, overwrite=True, min_size=1):
+def download_from_mast(tab, path=None, verbose=True, overwrite=False, use_token=True, base_url=None, cloud_only=False, **kwargs):
+    """
+    Download files from MAST API with `astroquery.mast.Observations.download_file`
+    
+    Parameters
+    ----------
+    tab : table, list
+        Table from MAST API query with minimal column ``dataURI``
+        or ``dataURL``.  If a `list`, then assumes they are strings of 
+        ``dataURL``/``dataURI`` names.
+    
+    path : str
+        Output path, defaults to current working diretory
+    
+    verbose : bool
+        Print status messages [deprecated, now uses `logging`]
+    
+    overwrite : bool
+        Overwrite existing files
+    
+    use_token : bool
+        Try to use a MAST token defined in a ``MAST_TOKEN`` environment 
+        variable.  See https://auth.mast.stsci.edu/info for info about the 
+        token authentication.
+    
+    base_url : str
+        A base url to use when downloading.  Default is the MAST Portal API
+    
+    cloud_only : bool
+        See `astroquery.mast.Observations.download_file`
+        
+    Returns
+    -------
+    resp : dict
+        Dict of responses from `astroquery.mast.Observations.download_file`
+        
+    """
+    from astroquery.mast import Observations
+    log = logging.getLogger()
+    
+    if (os.getenv('MAST_TOKEN') is None) | (not use_token):
+        session = Observations
+    else:
+        try:
+            session = Observations(mast_token=os.getenv('MAST_TOKEN'))
+        except:
+            session = Observations(token=os.getenv('MAST_TOKEN'))
+    
+    # Input is a list
+    if isinstance(tab, list):
+        tab = Table(names=['dataURI'], rows=[[u] for u in tab])
+    
+    if path is not None:
+        if not os.path.exists(path):
+            log.info(f'mkdir {path}')
+            os.makedirs(path)
+            
+    kws = {'local_path': path, 
+           'cache':(not overwrite), 
+           'base_url':base_url,
+           'cloud_only':cloud_only}
+    
+    resp = {}
+    for row in tab:     
+        if 'dataURI' in row.colnames:
+            _uri = row['dataURI']
+        else:
+            _uri = row['dataURL']
+
+        _file = os.path.basename(_uri)
+            
+        if path is None:
+            out_file = _file
+        else:
+            out_file = os.path.join(path, os.path.basename(_file))
+            kws['local_path'] = out_file
+            
+        if os.path.exists(out_file) & (not overwrite):
+            log.info(f'{out_file} exists, skip')
+            resp[out_file] = ('EXISTS', None, None)
+            continue
+                
+        # Download the data   
+        log.info(f"Download: {out_file}")
+             
+        payload = {"uri":_uri}        
+        resp[out_file] = session.download_file(_uri, **kws)
+    
+    return resp
+
+
+def old_download_from_mast(tab, path='./', verbose=True, overwrite=True, min_size=1, delete_small=True):
     """
     Download files from MAST API
     
     Parameters
     ----------
-    tab : table
-        Table from MAST API query with minimal columns ``filename``, 
-        ``dataURI``.
+    tab : table, list
+        Table from MAST API query with minimal column ``dataURI``
+        or ``dataURL``.  If a `list`, then assumes they are strings of 
+        ``dataURL``/``dataURI`` names.
     
-    out_path : str
+    path : str
         Output path
     
     verbose : bool
-        Print status messages
+        Print status messages [deprecated, now uses `logging`]
     
     overwrite : bool
         Overwrite existing files
@@ -274,49 +368,80 @@ def download_from_mast(tab, out_path='./', verbose=True, overwrite=True, min_siz
     min_size : float
         Minimum size in megabits to check if the downloaded file is rather
         an `Access Denied` file
+      
+    delete_small : bool
+        Remove the file if it failed the `min_size` test
+    
+    Returns
+    -------
+    outlist : list
+        List of valid downloaded files
         
     """
     import requests
     import os
+    log = logging.getLogger()
     
     download_url = 'https://mast.stsci.edu/api/v0.1/Download/file?'
     
-    if not os.path.exists(out_path):
-        if verbose:
-            print(f'mkdir {out_path}')
-            os.makedirs(out_path)
+    # Input is a list
+    if isinstance(tab, list):
+        tab = Table(names=['dataURI'], rows=[[u] for u in tab])
+        
+    if not os.path.exists(path):
+        log.info(f'mkdir {path}')
+        os.makedirs(path)
+    
+    outlist = []
     
     for row in tab:     
+        if 'dataURI' in row.colnames:
+            _uri = row['dataURI']
+        else:
+            _uri = row['dataURL']
 
-        out_file = os.path.join(out_path, os.path.basename(row['filename']))
+        if 'filename' in row.colnames:
+            _file = row['filename']
+        else:
+            _file = os.path.basename(_uri)
+            
+        out_file = os.path.join(path, os.path.basename(_file))
         
         if os.path.exists(out_file) & (not overwrite):
-            if verbose:
-                print(f'{out_file} exists')
-                continue
+            log.info(f'{out_file} exists, skip')
+            outlist.append(out_file)
+            continue
                 
-        # Download the data
-        payload = {"uri":row['dataURI']}
+        # Download the data   
+        log.info(f"Download: {out_file}")
+             
+        payload = {"uri":_uri}        
         resp = requests.get(download_url, params=payload)
-
-        # save to file
+        
+        # save to file        
         with open(out_file,'wb') as FLE:
             FLE.write(resp.content)
         
         # check for file 
         if not os.path.isfile(out_file):
-            if verbose:
-                print("ERROR: " + out_file + " failed to download.")
+            # No file
+            msg = f'{out_file} failed to download.'
+            log.warning(msg)
         else:
             fs = os.path.getsize(out_file)/1e6
             if fs < min_size:
-                print(f"WARNING: {out_file} is {fs:.1} Mb so is probably 'Access Denied'")
+                msg = f"{out_file} is {fs:.1} Mb so is probably "
+                msg += "'Access Denied'"
+                log.warning(msg)
+                
+                if delete_small:
+                    os.remove(out_file)
             else:
-                if verbose:
-                    print("COMPLETE: ", out_file)
-        
+                log.info(f"Complete: {out_file} ({fs:.1} Mb)")
+                outlist.append(out_file)
+    
+    return outlist
 
-###############
 
 def table_from_info(info):
     """
